import { ReactElement } from "react";
import {
  Breadcrumb,
  BreadcrumbItem,
  BreadcrumbLink,
  BreadcrumbList,
  BreadcrumbSeparator,
} from "@/app/components/ui/breadcrumb";
import { capitalizeFirstLetter } from "@/app/common/string-utils";
import { DocsContentMetadata } from "@/app/common/documentation";

type DocsBreadcrumbProps = {
  /**
   * The page to render the breadcrumb for.
   */
  page: DocsContentMetadata;
};

export function DocsBreadcrumb({ page }: DocsBreadcrumbProps): ReactElement {
  const slugParts: string[] = page.slug.split("/");
  const isHome: boolean = slugParts.length == 1;

  return (
    <Breadcrumb>
      <BreadcrumbList>
        <BreadcrumbItem>
          <BreadcrumbLink href={`/docs`}>Home</BreadcrumbLink>
        </BreadcrumbItem>
        {!isHome &&
          slugParts.map((slug, index, array) => {
            const path: string = array.slice(0, index + 1).join("/");
            const name: string = slug.includes("-")
              ? slug.split("-").map(capitalizeFirstLetter).join(" ")
              : capitalizeFirstLetter(slug);

            return (
              <div key={slug} className="flex items-center ">
                <BreadcrumbSeparator className="pr-1.5" />
                <BreadcrumbItem>
                  <BreadcrumbLink href={`/docs/${path}`}>{capitalizeFirstLetter(name)}</BreadcrumbLink>
                </BreadcrumbItem>
              </div>
            );
          })}
      </BreadcrumbList>
    </Breadcrumb>
  );
}
