import { CachedBedrockMinecraftServer, CachedJavaMinecraftServer } from "mcutils-library";
import Image from "next/image";
import { ReactElement } from "react";
import { CodeDialog } from "../code-dialog";
import { Button } from "../ui/button";
import { CacheInformation } from "@/app/components/cache-information";
import { ReloadPageButton } from "@/app/components/reload-page-button";

type ServerViewProps = {
  /**
   * The server to display.
   */
  server: CachedJavaMinecraftServer | CachedBedrockMinecraftServer;

  /**
   * The favicon for the server.
   */
  favicon: string | undefined;
};

export function ServerView({ server, favicon }: ServerViewProps): ReactElement {
  return (
    <div className="flex relative flex-col gap-2 items-center w-screen">
      <div>
        <Image
          src={`https://api.mcutils.xyz/server/java/preview/${server.hostname}`}
          alt={"The server preview"}
          width={650}
          height={256}
          unoptimized
        />
      </div>
      <div className="flex gap-2 flex-wrap justify-center">
        <ReloadPageButton />
        <CodeDialog
          title="Server Data"
          description="The servers's data from the API"
          code={JSON.stringify(server, undefined, 2)}
        >
          <Button>View as JSON</Button>
        </CodeDialog>
        <CacheInformation cache={server.cache}>
          <Button>Cache Information</Button>
        </CacheInformation>
      </div>
    </div>
  );
}
